@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.43';
+our $VERSION = '0.44';
 
 use Courriel::HeaderAttribute;
 use Courriel::Helpers qw( parse_header_with_attributes );
@@ -96,8 +96,8 @@ sub _attributes_as_string {
 {
     my $validator = validation_for(
         params => [
-            name  => { isa => NonEmptyStr, optional => 1 },
-            value => { isa => NonEmptyStr },
+            name  => { type => NonEmptyStr, optional => 1 },
+            value => { type => NonEmptyStr },
         ],
         named_to_list => 1,
     );
